﻿'Project: StreamReader
'Author: Anthony DePinto 
'Date: Fall 2014 
'Description: 
' Read a file sequentially and display contents based on
' account type specified by user (credit, debit or zero balances).
Imports System.IO ' using classes from this namespace

Public Class CreditInquiry
    Dim FileNameString As String ' name of file containing account data

    Enum AccountType ' constants representing account types
        CREDIT
        DEBIT
        ZERO
    End Enum ' AccountTypes

    ' opens a file in which accounts are stored
    Private Sub OpenToolStripMenuItem_Click(sender As Object,
       e As EventArgs) Handles OpenToolStripMenuItem.Click

        Dim FileDialogResult As DialogResult ' stores result of Open dialog

        ' create dialog box enabling user to open file
        Using AccountOpenFileDialog As New OpenFileDialog()
            FileDialogResult = AccountOpenFileDialog.ShowDialog()
            FileNameString = AccountOpenFileDialog.FileName ' get specified file name
        End Using ' automatic call to fileChooser.Dispose() occurs here

        ' if user did not click Cancel, enable Buttons
        If FileDialogResult <> Windows.Forms.DialogResult.Cancel Then
            NegativeBalanceButton.Enabled = True
            PositiveBalanceButton.Enabled = True
            ZeroBalanceButton.Enabled = True
        End If
    End Sub ' OpenToolStripMenuItem_Click

    ' exit the application
    Private Sub ExitToolStripMenuItem_Click(sender As Object,
       e As EventArgs) Handles ExitToolStripMenuItem.Click

        Application.Exit() ' terminate the application
    End Sub ' ExitToolStripMenuItem_Click

    ' display accounts with negative balances
    Private Sub NegativeBalanceButton_Click(sender As Object,
       e As EventArgs) Handles NegativeBalanceButton.Click

        DisplayAccounts(AccountType.CREDIT) ' displays credit balances
    End Sub ' creditBalancesButton_Click

    ' display accounts with positive balances
    Private Sub PositiveBalanceButton_Click(sender As Object,
       e As EventArgs) Handles PositiveBalanceButton.Click

        DisplayAccounts(AccountType.DEBIT) ' displays debit balances
    End Sub ' debitBalancesButton_Click

    ' display accounts with zero balances
    Private Sub ZeroBalanceButton_Click(sender As Object,
       e As EventArgs) Handles ZeroBalanceButton.Click

        DisplayAccounts(AccountType.ZERO) ' displays credit balances
    End Sub ' zeroBalancesButton_Click

    ' display accounts of specified type
    Sub DisplayAccounts(inAccountType As AccountType)
        Dim AccountStreamReader As StreamReader = Nothing

        ' read and display file information
        Try
            accountsTextBox.Text = "The accounts are:" & vbCrLf

            ' open file for reading
            AccountStreamReader = New StreamReader(FileNameString)

            ' read file and display lines that match the balance type
            Do While Not AccountStreamReader.EndOfStream ' while not end of file
                Dim LineString As String = AccountStreamReader.ReadLine() ' read line
                Dim FieldsString() As String = LineString.Split(","c) ' split into fields

                ' get data from fields array
                Dim AccountNumberInteger As Integer = Convert.ToInt32(FieldsString(0))
                Dim FirstNameString As String = FieldsString(1)
                Dim LastNameString As String = FieldsString(2)
                Dim BalanceDecimal As Decimal = Convert.ToDecimal(FieldsString(3))

                If ShouldDisplay(BalanceDecimal, inAccountType) Then
                    accountsTextBox.AppendText(AccountNumberInteger.ToString & vbTab &
                       FirstNameString & vbTab & LastNameString & vbTab &
                       BalanceDecimal.ToString("C") & vbCrLf)
                End If
            Loop
        Catch ex As IOException
            MessageBox.Show("Cannot Read File", "Error",
               MessageBoxButtons.OK, MessageBoxIcon.Error)
        Finally ' ensure that file gets closed
            If AccountStreamReader IsNot Nothing Then
                Try
                    AccountStreamReader.Close() ' close StreamReader
                Catch ex As IOException
                    MessageBox.Show("Error closing file", "Error",
                       MessageBoxButtons.OK, MessageBoxIcon.Error)
                End Try
            End If
        End Try
    End Sub ' DisplayAccounts

   ' determine whether to display given account based on the balance
    Function ShouldDisplay(inBalanceDecimal As Double,
                           inType As AccountType) As Boolean

        If inBalanceDecimal < 0 AndAlso inType = AccountType.CREDIT Then
            Return True ' record should be displayed
        ElseIf inBalanceDecimal > 0 AndAlso inType = AccountType.DEBIT Then
            Return True ' record should be displayed
        ElseIf inBalanceDecimal = 0 AndAlso inType = AccountType.ZERO Then
            Return True ' record should be displayed
        End If

        Return False ' record should not be displayed
    End Function ' ShouldDisplay


End Class ' Credit Inquiry

